@@ -101,7 +101,7 @@ static int running_on_valgrind = -1;
  *
  * For small requests, the allocator sub-allocates <Big> blocks of memory.
  * Requests greater than SMALL_REQUEST_THRESHOLD bytes are routed to the
- * system's allocator.
+ * system's allocator. 
  *
  * Small requests are grouped in size classes spaced 8 bytes apart, due
  * to the required valid alignment of the returned address. Requests of
@@ -134,7 +134,7 @@ static int running_on_valgrind = -1;
  *       65-72                   72                       8
  *        ...                   ...                     ...
  *      497-504                 504                      62
- *      505-512                 512                      63
+ *      505-512                 512                      63 
  *
  *      0, SMALL_REQUEST_THRESHOLD + 1 and up: routed to the underlying
  *      allocator.
@@ -167,7 +167,7 @@ static int running_on_valgrind = -1;
  * this value according to your application behaviour and memory needs.
  *
  * The following invariants must hold:
- *      1) ALIGNMENT <= SMALL_REQUEST_THRESHOLD <= 512
+ *      1) ALIGNMENT <= SMALL_REQUEST_THRESHOLD <= 256
  *      2) SMALL_REQUEST_THRESHOLD is evenly divisible by ALIGNMENT
  *
  * Note: a size threshold of 512 guarantees that newly created dictionaries
@@ -176,7 +176,7 @@ static int running_on_valgrind = -1;
  * Although not required, for better performance and space efficiency,
  * it is recommended that SMALL_REQUEST_THRESHOLD is set to a power of 2.
  */
-#define SMALL_REQUEST_THRESHOLD 512
+#define SMALL_REQUEST_THRESHOLD 512 
 #define NB_SMALL_SIZE_CLASSES   (SMALL_REQUEST_THRESHOLD / ALIGNMENT)
 
 /*
@@ -209,12 +209,12 @@ static int running_on_valgrind = -1;
  * usually an address range reservation for <Big> bytes, unless all pages within
  * this space are referenced subsequently. So malloc'ing big blocks and not
  * using them does not mean "wasting memory". It's an addressable range
- * wastage...
+ * wastage... 
  *
  * Arenas are allocated with mmap() on systems supporting anonymous memory
  * mappings to reduce heap fragmentation.
  */
-#define ARENA_SIZE              (256 << 10)     /* 256KiB */
+#define ARENA_SIZE              (256 << 10)     /* 256KB */
 
 #ifdef WITH_MEMORY_LIMITS
 #define MAX_ARENAS              (SMALL_MEMORY_LIMIT / ARENA_SIZE)
@@ -619,7 +619,7 @@ new_arena(void)
 #else
     address = malloc(ARENA_SIZE);
     err = (address == 0);
-#endif
+#endif    
     if (err) {
         /* The allocation failed: return NULL after putting the
          * arenaobj back.
@@ -1413,38 +1413,6 @@ pool_is_in_list(const poolp target, poolp list)
 
 #endif  /* Py_DEBUG */
 
-static void *
-_PyMem_Malloc(size_t nbytes)
-{
-    if (nbytes > (size_t)PY_SSIZE_T_MAX) {
-        return NULL;
-    }
-    if (nbytes == 0) {
-        nbytes = 1;
-    }
-    return malloc(nbytes);
-}
-
-static void *
-_PyMem_Realloc(void *p, size_t nbytes)
-{
-    if (nbytes > (size_t)PY_SSIZE_T_MAX) {
-        return NULL;
-    }
-    if (nbytes == 0) {
-        nbytes = 1;
-    }
-    return realloc(p, nbytes);
-}
-
-
-static void
-_PyMem_Free(void *p)
-{
-    free(p);
-}
-
-
 /* Let S = sizeof(size_t).  The debug malloc asks for 4*S extra bytes and
    fills them with useful stuff, here calling the underlying malloc's result p:
 
@@ -1511,7 +1479,7 @@ _PyObject_DebugCheckAddress(const void *p)
 
 /* generic debug memory api, with an "id" to identify the API in use */
 void *
-_PyObject_DebugMallocApi(char api, size_t nbytes)
+_PyObject_DebugMallocApi(char id, size_t nbytes)
 {
     uchar *p;           /* base address of malloc'ed block */
     uchar *tail;        /* p + 2*SST + nbytes == pointer to tail pad bytes */
@@ -1523,18 +1491,13 @@ _PyObject_DebugMallocApi(char api, size_t nbytes)
         /* overflow:  can't represent total as a size_t */
         return NULL;
 
-    if (api == _PYMALLOC_OBJ_ID) {
-        p = (uchar *)PyObject_Malloc(total);
-    }
-    else {
-        p = (uchar *)_PyMem_Malloc(total);
-    }
+    p = (uchar *)PyObject_Malloc(total);
     if (p == NULL)
         return NULL;
 
-    /* at p, write size (SST bytes), api (1 byte), pad (SST-1 bytes) */
+    /* at p, write size (SST bytes), id (1 byte), pad (SST-1 bytes) */
     write_size_t(p, nbytes);
-    p[SST] = (uchar)api;
+    p[SST] = (uchar)id;
     memset(p + SST + 1 , FORBIDDENBYTE, SST-1);
 
     if (nbytes > 0)
@@ -1566,12 +1529,7 @@ _PyObject_DebugFreeApi(char api, void *p)
     nbytes += 4*SST;
     if (nbytes > 0)
         memset(q, DEADBYTE, nbytes);
-    if (api == _PYMALLOC_OBJ_ID) {
-        PyObject_Free(q);
-    }
-    else {
-        _PyMem_Free(q);
-    }
+    PyObject_Free(q);
 }
 
 void *
@@ -1594,7 +1552,7 @@ _PyObject_DebugReallocApi(char api, void *p, size_t nbytes)
         /* overflow:  can't represent total as a size_t */
         return NULL;
 
-    if (nbytes <= original_nbytes) {
+    if (nbytes < original_nbytes) {
         /* shrinking:  mark old extra memory dead */
         memset(q + nbytes, DEADBYTE, original_nbytes - nbytes + 2*SST);
     }
@@ -1603,20 +1561,9 @@ _PyObject_DebugReallocApi(char api, void *p, size_t nbytes)
      * case we didn't get the chance to mark the old memory with DEADBYTE,
      * but we live with that.
      */
-    if (api == _PYMALLOC_OBJ_ID) {
-        q = (uchar *)PyObject_Realloc(q - 2*SST, total);
-    }
-    else {
-        q = (uchar *)_PyMem_Realloc(q - 2*SST, total);
-    }
-    if (q == NULL) {
-        if (nbytes <= original_nbytes) {
-            /* bpo-31626: the memset() above expects that realloc never fails
-               on shrinking a memory block. */
-            Py_FatalError("Shrinking reallocation failed");
-        }
+    q = (uchar *)PyObject_Realloc(q - 2*SST, total);
+    if (q == NULL)
         return NULL;
-    }
 
     write_size_t(q, nbytes);
     assert(q[SST] == (uchar)api);
